CaPSID
========
**CaPSID** (Computational Pathogen Sequence IDentification) is a comprehensive
open source platform which integrates a high-performance computational pipeline
for pathogen sequence identification and characterization in human genomes and
transcriptomes together with a scalable results database and a user-friendly
web-based software application for managing, querying and visualizing results.

**Project Leader** Vincent Ferretti

**Development Team** Ivan Borozan, Philippe Laflamme, Shane Wilson

Downloading and using **CaPSID** is free, if you use **CaPSID** or its code in your
work please acknowledge **CaPSID** by referring to its GitHub homepage https://github.com/capsid. 
This is important for us since obtaining grants is one significant way to fund
planning and implementation for our project. Also if you find **CaPSID** useful
in your research feel free to let us know.

Getting Started
---------------
You will need a MongoDB database, a Python 2.7 installation and a Java Web Server. For more details, read the wiki:

  https://github.com/capsid/capsid/wiki/

License and Copyright
---------------------
Licensed under the GNU General Public License, Version 3.0. See LICENSE for more details.

Copyright 2011 The Ontario Institute for Cancer Research.

Acknowledgement
---------------
This project is supported by the Ontario Institute for Cancer Research
(OICR) through funding provided by the government of Ontario, Canada.
